@@ -91,34 +91,41 @@ class Condenser(HeatExchanger):
     printout : boolean
         Include this component in the network's results printout.
 
-    Q : str, float, tespy.tools.data_containers.ComponentProperties
+    Q : float, dict
         Heat transfer, :math:`Q/\text{W}`.
 
-    pr1 : str, float, tespy.tools.data_containers.ComponentProperties
+    pr1 : float, dict, :code:`"var"`
         Outlet to inlet pressure ratio at hot side, :math:`pr/1`.
 
-    pr2 : str, float, tespy.tools.data_containers.ComponentProperties
+    pr2 : float, dict, :code:`"var"`
         Outlet to inlet pressure ratio at cold side, :math:`pr/1`.
 
-    zeta1 : str, float, tespy.tools.data_containers.ComponentProperties
+    zeta1 : float, dict, :code:`"var"`
         Geometry independent friction coefficient at hot side,
         :math:`\frac{\zeta}{D^4}/\frac{1}{\text{m}^4}`.
 
-    zeta2 : str, float, tespy.tools.data_containers.ComponentProperties
+    zeta2 : float, dict, :code:`"var"`
         Geometry independent friction coefficient at cold side,
         :math:`\frac{\zeta}{D^4}/\frac{1}{\text{m}^4}`.
 
-    kA : float, tespy.tools.data_containers.ComponentProperties
-        Area independent heat transition coefficient,
+    ttd_l : float, dict
+        Lower terminal temperature difference :math:`ttd_\mathrm{l}/\text{K}`.
+
+    ttd_u : float, dict
+        Upper terminal temperature difference (referring to saturation
+        temprature of condensing fluid) :math:`ttd_\mathrm{u}/\text{K}`.
+
+    kA : float, dict
+        Area independent heat transfer coefficient,
         :math:`kA/\frac{\text{W}}{\text{K}}`.
 
     kA_char : tespy.tools.data_containers.DataContainerSimple
-        Area independent heat transition coefficient characteristic.
+        Area independent heat transfer coefficient characteristic.
 
-    kA_char1 : tespy.tools.characteristics.CharLine, tespy.tools.data_containers.ComponentCharacteristics
+    kA_char1 : tespy.tools.characteristics.CharLine, dict
         Characteristic line for hot side heat transfer coefficient.
 
-    kA_char2 : tespy.tools.characteristics.CharLine, tespy.tools.data_containers.ComponentCharacteristics
+    kA_char2 : tespy.tools.characteristics.CharLine, dict
         Characteristic line for cold side heat transfer coefficient.
 
     subcooling : boolean
@@ -212,7 +219,7 @@ class Condenser(HeatExchanger):
             'kA': dc_cp(
                 min_val=0, num_eq=1, func=self.kA_func, latex=self.kA_func_doc,
                 deriv=self.kA_deriv),
-            'td_log': dc_cp(min_val=0),
+            'td_log': dc_cp(min_val=0, is_result=True),
             'ttd_u': dc_cp(
                 min_val=0, num_eq=1, func=self.ttd_u_func,
                 deriv=self.ttd_u_deriv, latex=self.ttd_u_func_doc),
@@ -456,7 +463,7 @@ class Condenser(HeatExchanger):
             r'T_\mathrm{out,2}}{\ln{\frac{T_\mathrm{out,1}-'
             r'T_\mathrm{in,2}}{T_\mathrm{sat}\left( p_\mathrm{in,1}\right)'
             r'- T_\mathrm{out,2}}}}\\' + '\n'
-            r'f_\mathrm{kA}=&\frac{2}{\frac{1}{f\left(X_2\right)}+'
+            r'f_\mathrm{kA}=&\frac{2}{\frac{1}{f\left(X_1\right)}+'
             r'\frac{1}{f\left(X_2\right)}}\\' + '\n'
             r'\end{split}'
         )
